==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/include/WSCvspace.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVSPACE_H
#define WSCVSPACE_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvspace_VER  1000
#include <WSDprivateTimer.h>

class WSCvspace   :public WSCngbase{
  protected:
    unsigned _ext:1; 
    unsigned _orientation:1; 

    WSMFpropertyDef(WSNextension,      WSCbool,      _ext);
    WSMFpropertyDef(WSNorientation,    WSCuchar,      _orientation);
    static void _resize_work(WSCbase*);
    static void _adjust(WSCbase*,WSCbool vert);
  public:

    WSCvspace(WSCbase* base, char* name);

    WSMFguiClassDef(WSCvspace,WSCngbase);
    WSMFversionDef(WSCvspace);
};

#endif //WSCVSPACE_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSCvspace.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCVSPACE_H
#define WSCVSPACE_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvspace_VER  1000
#include <WSDprivateTimer.h>

class WSCvspace   :public WSCngbase{
  protected:
    unsigned _ext:1; 
    unsigned _orientation:1; 

    WSMFpropertyDef(WSNextension,      WSCbool,      _ext);
    WSMFpropertyDef(WSNorientation,    WSCuchar,      _orientation);
    WSDLEX32 static void _resize_work(WSCbase*);
    WSDLEX32 static void _adjust(WSCbase*,WSCbool vert);
  public:

    WSDLEX32 WSCvspace(WSCbase* base, char* name);

    WSMFguiClassDef(WSCvspace,WSCngbase);
    WSMFversionDef(WSCvspace);
};

#endif //WSCVSPACE_H
